| Title: | 'Rcpp' Bindings to tomlplusplus Parser for "Tom's Obvious Markup Language" |
|---|---|
| Description: | The configuration format defined by 'TOML' (which expands to "Tom's Obvious Markup Language") specifies an excellent format (described at <https://toml.io/en/>) suitable for both human editing as well as the common uses of a machine-readable format. This package uses 'Rcpp' to connect the 'toml++' parser written by Mark Gillard (in C++17) to R. |
| Authors: | Dirk Eddelbuettel |
| Maintainer: | Dirk Eddelbuettel <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.0.1 |
| Built: | 2026-05-28 07:10:06 UTC |
| Source: | https://github.com/eddelbuettel/rcpptomlplusplus |
The configuration format defined by 'TOML' (which expands to "Tom's Obvious Markup Language") specifies an excellent format (described at <https://toml.io/en/>) suitable for both human editing as well as the common uses of a machine-readable format. This package uses 'Rcpp' to connect the 'toml++' parser written by Mark Gillard (in C++17) to R.
Index of help topics:
parseTOML Parse a TOML file
RcppTomlPlusPlus-package
'Rcpp' Bindings to tomlplusplus Parser for
"Tom's Obvious Markup Language"
Dirk Eddelbuettel <[email protected]>
Dirk Eddelbuettel
The function parseTOML, also aliased to tomlparse and parseToml,
parse TOML content inout. This is usually a file given by its name, or a character variable
with a TOML expression.
parseTOML(input, verbose = FALSE, fromFile = TRUE, includize = FALSE, escape = TRUE) tomlparse(...) parseToml(...) ## S3 method for class 'toml' print(x, ...) ## S3 method for class 'toml' summary(object, ...)parseTOML(input, verbose = FALSE, fromFile = TRUE, includize = FALSE, escape = TRUE) tomlparse(...) parseToml(...) ## S3 method for class 'toml' print(x, ...) ## S3 method for class 'toml' summary(object, ...)
input |
[character] TOML input, either as chracter value or path to TOML file |
verbose |
[logical] Optional verbosity flag, no current effect |
fromFile |
[logical] Optional with default value ‘TRUE’ indicating parsing from file |
includize |
[logical] Optional legacy option, no current effect |
escape |
[logical] Optional boolean whether strings should be escaped, defaults to ‘TRUE’ |
... |
Used for aliased function and S3 methods |
x |
Used for S3 method |
object |
Used for S3 method |
This implementation uses the ‘tomlplusplus’ library by Mark Gillar (see https://github.com/marzer/tomlplusplus) which is TOML 1.0 compliant. In earlier work the package used the ‘cpptoml’ library by Chase Geigle (see https://github.com/skystrife/cpptoml for which development ceased once TOML 0.5.0 parity was reached.
A list object with the parsed content as an S3 object of class ‘toml’